@@ -51,7 +51,7 @@ printGeneral <- function(status,
     }
     df.endpoint$endpoint <- endpoint
     df.endpoint$type <- c("binary","continuous","time to event")[type]
-    df.endpoint$operator <- c("lower is favorable","higher is favorable")[1 + (operator == ">0")]
+    df.endpoint$operator <- ifelse(operator>0,"higher is favorable","lower is favorable")
     df.endpoint$threshold[type!=1] <- threshold[type!=1]
     df.endpoint$event[type==3] <- status[type==3]
     
@@ -89,10 +89,14 @@ printGeneral <- function(status,
     }
     if(D>1){
         cat("   - neutral pairs: ")
-        if(neutral.as.uninf){
+        if(all(neutral.as.uninf)){
             cat("re-analyzed using lower priority endpoints \n")
-        }else{
+        }else if(all(!neutral.as.uninf)){
             cat("ignored at lower priority endpoints \n")
+        }else{
+            cat("re-analyzed using lower priority endpoints for endpoint ",
+                paste(which(neutral.as.uninf), collapse = ", "),
+                " \n                    otherwise ignored at lower priority endpoints \n",sep="")
         }
     }
     if(D.TTE>0){
